powered by
Start an ontology
start_ontology( name = NULL, version = NULL, path = NULL, code = ".xx", description = NULL, homepage = NULL, uri_prefix = NULL, license = NULL, notes = NULL )
it returns the new, empty ontology and also stores that within the directory specified in path.
path
character(1) the path of the ontology.
character(1)
character(1) the version of the ontology.
character(1) the path where the ontology shall be stored.
double(1) format of a single code snippet that is concatenated for nested levels.
double(1)
character(1) a brief description of the new ontology.
character(1) the URL to the homepage of the new ontology.
character(1) the basic URL to construct URIs for all concepts.
character(1) any string describing the license under which this ontology can be (re)used.
character(1) any notes that might apply to this ontology.
start_ontology(name = "crops", path = tempdir())
Run the code above in your browser using DataLab